import { fileURLToPath, URL } from 'node:url';

import { defineConfig } from 'vite';
import vue from '@vitejs/plugin-vue';
import vueJsx from '@vitejs/plugin-vue-jsx';
import { CodeInspectorPlugin } from 'code-inspector-plugin';
import autoprefixer from 'autoprefixer';
import tailwindcss from 'tailwindcss';
import AutoImport from 'unplugin-auto-import/vite';
import Components from 'unplugin-vue-components/vite';
import { ElementPlusResolver } from 'unplugin-vue-components/resolvers';
import { visualizer } from 'rollup-plugin-visualizer';

// https://vitejs.dev/config/
export default defineConfig({
	plugins: [
		CodeInspectorPlugin({
			bundler: 'vite',
			hotKeys: ['shiftKey'],
		}),
		vue(),
		vueJsx(),
		AutoImport({
			resolvers: [
				ElementPlusResolver({
					importStyle: 'sass',
				}),
			],
			imports: ['vue', '@vueuse/core', 'vue-router', 'pinia'],
		}),

		Components({
			resolvers: [
				ElementPlusResolver({
					importStyle: 'sass',
				}),
			],
		}),
		visualizer({
			gzipSize: true,
			brotliSize: true,
			emitFile: false,
			open: false, //如果存在本地服务端口，将在打包后自动展示
		}),
	],
	base: './',
	server: {
		host: '0.0.0.0',
	},
	resolve: {
		alias: {
			'@': fileURLToPath(new URL('./src', import.meta.url)),
		},
	},
	css: {
		preprocessorOptions: {
			css: { charset: false },
			scss: {
				additionalData: '@use "@/styles/element.scss";',
				silenceDeprecations: ['legacy-js-api'],
			},
		},

		postcss: {
			plugins: [tailwindcss, autoprefixer],
		},
	},
});
